@@ -33,19 +33,13 @@ Making a checkout of the Nose_ trunk::
 
 .. _Nose: http://somethingaboutorange.com/mrl/projects/nose/
 
-------------
-Requirements
-------------
+-------
+Install
+-------
 
-You first need to install the pysvn_ library.
-Unfortunately it is not available as an easy_install package, so it can't
-be automated in the setup script.
-In Debian and Ubuntu this package is named "python-svn" (not "python-subversion"
-which is a different package).
-In Mandriva it is named "python-pysvn" (not "python-svn" which is a different
-package).
-
-.. _pysvn:  http://pysvn.tigris.org/
+Just type ``easy_install hgsvn``. If easy_install is not available on your
+computer, download and uncompress the source tarball, then type ``python
+setup.py install``.
 
 --------
 Features
@@ -64,11 +58,8 @@ Metadata
 --------
 
 hgsvn reflects commit times (using the local timezone) and commit author names.
-Commit messages can contain Unicode characters.
-
-File copies and renames as reflected as well, provided they occur inside the
-branch. SVN externals are purposefully ignored and won't be added to your
-Mercurial repository.
+Commit messages can contain Unicode characters. File copies and renames as
+reflected as well, provided they occur inside the branch.
 
 Tags
 ----
@@ -124,14 +115,49 @@ for all the changesets in the SVN branch (therefore, after rev. 1138).
 This way, you can easily track how the branch diverges from the trunk, but also
 do merges, etc.
 
+-----------
+Limitations
+-----------
+
+SVN externals are purposefully ignored and won't be added to your Mercurial
+repository.
+
+There is no straightforward way to push back changes to the SVN repository.
+For now hgsvn is primarily intended at doing local mirrors, private branches,
+or patch-driven development (by submitting patches to project maintainers,
+which is necessary if you don't have SVN commit access anyway). However, an
+``hgpushsvn`` command is in the plans that will allow one day to push all
+changes to SVN automatically.
+
 -------
 History
 -------
 
+hgsvn 0.1.2
+-----------
+
+Improvements:
+
+* Automatically generate ``.hgignore`` file. Not only does it produce cleaner
+  output for commands like ``hg status``, but it speeds things up as well.
+* ``hgpullsvn`` is more robust in the face of errors and user interruptions.
+* Try to be Windows-compatible by not using the commands module.
+* Remove dependency on the pysvn library; we use the XML output option of SVN
+  commands instead.
+
+Bug fixes:
+
+* Fix a bug in parent repository detection.
+* Detect the wicked case where the SVN branch has been overwritten with
+  contents of another branch (witnessed with Nose trunk and 0.10-dev branch).
+  We can't properly handle this situation, so fail with an explicit message.
+* ``svn info`` on base repository URL does not always succeed, use the specific
+  project URL instead (reported by Larry Hastings).
+
 hgsvn 0.1.1
 -----------
 
-Fixes:
+Bug fixes:
 
 * pysvn doesn't really ignore externals, so use the command line for
   ``svn update`` instead (otherwise we get failures for obsolete URLs)
@@ -153,7 +179,7 @@ __all__ = []
 
 __author__ = 'Antoine Pitrou'
 __license__ = 'GNU General Public License (version 2 or later)'
-__versioninfo__ = (0, 1, 1)
+__versioninfo__ = (0, 1, 2)
 
 base_version = '.'.join(map(str, __versioninfo__))
 full_version = base_version
