@@ -2,23 +2,23 @@
 
 from hgsvn.common import (
     run_command, run_hg, skip_dirs,
-    get_svn_rev, get_svn_rev_or_head, get_svn_rev_or_0,
+    hg_commit_from_svn_log_entry, hg_exclude_options,
+)
+from hgsvn.svnclient import (
     get_first_svn_log_entry, get_last_svn_log_entry,
-    hg_commit_from_svn_log_entry,
-    hg_exclude_options,
+    get_svn_info, get_svn_status, svn_checkout,
 )
 
 import sys
 import os
 import shutil
 import tempfile
-import pysvn
 import urllib # for unquoting URLs
 from itertools import chain
 from optparse import OptionParser
 
 
-# TODO: an option to enable/disable svn:externals (disabled by default?)
+# XXX add an option to enable/disable svn:externals?
 
 
 def main():
@@ -36,17 +36,11 @@ def main():
     local_repo = args and args.pop(0) or None
 
     # Get SVN info
-    svn_client = pysvn.Client()
-    if options.svn_rev:
-        l = svn_client.info2(svn_url, recurse=False,
-            revision=get_svn_rev(options.svn_rev))
-    else:
-        l = svn_client.info2(svn_url, recurse=False)
-    _, svn_info = l[0]
+    svn_info = get_svn_info(svn_url, options.svn_rev)
     # e.g. u'svn://svn.twistedmatrix.com/svn/Twisted'
-    repos_url = svn_info['repos_root_URL']
+    repos_url = svn_info['repos_url']
     # e.g. u'svn://svn.twistedmatrix.com/svn/Twisted/branches/xmpp-subprotocols-2178-2'
-    svn_url = svn_info['URL']
+    svn_url = svn_info['url']
     assert svn_url.startswith(repos_url)
     # e.g. u'/branches/xmpp-subprotocols-2178-2'
     svn_path = svn_url[len(repos_url):]
@@ -78,22 +72,22 @@ def main():
                 break
         if svn_copyfrom_path:
             print "SVN branch was copied from '%s' at rev %s" % (
-                svn_copyfrom_path, svn_copyfrom_revision.number)
+                svn_copyfrom_path, svn_copyfrom_revision)
         else:
             print "SVN branch isn't a copy"
     # This is the revision we will checkout from
-    svn_rev = get_svn_rev(svn_start_log['revision'].number)
+    svn_rev = svn_start_log['revision']
 
     # Initialize hg repo
     if not os.path.exists(".hg"):
         run_hg(["init"])
     if svn_copyfrom_path:
         # Try to find an hg repo tracking the SVN branch which was copied
-        copyfrom_branch = svn_copyfrom_path.lstrip("/")
+        copyfrom_branch = svn_copyfrom_path.split("/")[-1]
         hg_copyfrom = os.path.join("..", copyfrom_branch)
         if (os.path.exists(os.path.join(hg_copyfrom, ".hg")) and
             os.path.exists(os.path.join(hg_copyfrom, ".svn"))):
-            u = svn_client.info(hg_copyfrom).url
+            u = get_svn_info(hg_copyfrom)['url']
             if u != repos_url + svn_copyfrom_path:
                 print "SVN URL %s in working copy %s doesn't match, ignoring" % (u, hg_copyfrom)
             else:
@@ -104,7 +98,7 @@ def main():
                         continue
                     tag = line.split(None, 1)[0]
                     tag_num = int(tag.split(".")[1])
-                    if tag_num <= svn_rev.number and (not best_tag or best_tag < tag_num):
+                    if tag_num <= svn_copyfrom_revision and (not best_tag or best_tag < tag_num):
                         best_tag = tag_num
                 if not best_tag:
                     print "No hg tag matching rev %s in %s" % (svn_rev, hg_copyfrom)
@@ -112,23 +106,25 @@ def main():
                     run_hg(["pull", "-u", "-r", "svn.%d" % best_tag, hg_copyfrom])
     run_hg(["branch", svn_branch])
 
+    # Generate .hgignore file to ignore .svn directories
+    f = open(".hgignore", "a")
+    try:
+        f.write("\n# Automatically generated by `hgimportsvn`\nsyntax:glob\n.svn\n")
+    finally:
+        f.close()
+
     # Stay on the same filesystem so as to have fast moves
     checkout_dir = tempfile.mkdtemp(dir=".")
 
     try:
         # Get SVN manifest and checkout
-        print "* SVN checkout from rev %s" % svn_rev
-        svn_client.checkout(svn_url, checkout_dir, revision=svn_rev)
+        svn_checkout(svn_url, checkout_dir, svn_rev)
+        #svn_client.checkout(svn_url, checkout_dir, revision=svn_rev)
         svn_manifest = []
-        for st in svn_client.status(checkout_dir, ignore_externals=True):
-            # NOTE: st.is_versioned is unreliable because it is also set for
-            # ignored files not tracked by SVN
-            if st.entry:
-                u = st.entry.url
-                assert u.startswith(svn_url)
-                u = u[len(svn_url):].lstrip("/")
-                if u:
-                    svn_manifest.append(urllib.unquote(u))
+
+        for e in get_svn_status(checkout_dir):
+            if e['path'] and e['type'] == 'normal':
+                svn_manifest.append(e['path'])
         svn_files = set(skip_dirs(svn_manifest, checkout_dir))
         svn_dirs = sorted(set(svn_manifest) - svn_files)
         svn_files = list(svn_files)
